//-----------------------------------------------------------------------------
// Project            	RenderKit
// Class		G3DEventHandler
// Creator            	Philippe C.D. Robert
// Maintainer         	Philippe C.D. Robert
// Creation Date      	Sun Jul 16 23:23:46 CEST 2000
//
// Copyright (c) Philippe C.D. Robert
//
// The RenderKit is free software; you can redistribute it and/or modify it 
// under the terms of the GNU General Public License as published by the Free 
// Software Foundation
//
// $Id: G3DSDLEventHandler.h,v 1.8 2001/07/15 13:56:15 probert Exp $
//-----------------------------------------------------------------------------

#ifndef __G3DSDLEventHandler_h_INCLUDE
#define __G3DSDLEventHandler_h_INCLUDE

#import <Foundation/Foundation.h>

#include <SDL/SDL.h>

/*
 * Enumeration of valid key mods (possibly OR'd together) 
 *
 */

typedef enum {
  G3D_MOD_NONE  = 0x0000,
  G3D_MOD_LSHIFT= 0x0001,
  G3D_MOD_RSHIFT= 0x0002,
  G3D_MOD_LCTRL = 0x0040,
  G3D_MOD_RCTRL = 0x0080,
  G3D_MOD_LALT  = 0x0100,
  G3D_MOD_RALT  = 0x0200,
  G3D_MOD_LMETA = 0x0400,
  G3D_MOD_RMETA = 0x0800,
  G3D_MOD_NUM   = 0x1000,
  G3D_MOD_CAPS  = 0x2000,
  G3D_MOD_MODE  = 0x4000,
  G3D_MOD_RESERVED = 0x8000
} G3D_Mod;

#define G3D_MOD_CTRL	(G3D_MOD_LCTRL|G3D_MOD_RCTRL)
#define G3D_MOD_SHIFT	(G3D_MOD_LSHIFT|G3D_MOD_RSHIFT)
#define G3D_MOD_ALT	(G3D_MOD_LALT|G3D_MOD_RALT)
#define G3D_MOD_META	(G3D_MOD_LMETA|G3D_MOD_RMETA)

@interface G3DSDLEventHandler : NSObject
{
}

//-----------------------------------------------------------------------------
// Class methods
//-----------------------------------------------------------------------------

+ (G3DSDLEventHandler *)defaultHandler;

//-----------------------------------------------------------------------------
// General Event Handling
//-----------------------------------------------------------------------------

- (BOOL)getEvent:(SDL_Event *)ev;
- (NSString *)nameWithKeyEvent:(SDLKey)ev;

- (void)getKeyState:(Uint8 *)state;

- (SDLMod)modifierKeyState;
- (BOOL)isKeyPressed:(SDLKey)ev;

- (void)setKeyRepeatWithDelay:(int)del interval:(int)iv;

//-----------------------------------------------------------------------------
// Mouse Event Handling
//-----------------------------------------------------------------------------

- (int)getStateAtX:(int *)x y:(int *)y;
- (int)getRelativeStateAtX:(int *)x y:(int *)y;

- (void)setMouseAtX:(int)x y:(int)y;
- (void)centerMouse;

- (BOOL)isMouseActive;
- (void)activeMouse:(BOOL)yn;

- (void)showCursor;
- (void)hideCursor;

@end

extern NSString *G3DSDLEventHandlerException;

#endif
